@@ -1,6 +1,7 @@
-use crate::data::Source;
 use tanoshi_vm::bus::ExtensionBus;
 
+use crate::data::Index;
+
 pub async fn generate_json(bus: ExtensionBus) -> Result<(), Box<dyn std::error::Error>> {
     let path = std::path::Path::new("repo");
     let _ = std::fs::create_dir_all(path.join("library"));
@@ -9,14 +10,11 @@ pub async fn generate_json(bus: ExtensionBus) -> Result<(), Box<dyn std::error::
         .list()
         .await?
         .iter()
-        .map(|detail| Source {
-            id: detail.id,
-            name: detail.name.clone(),
-            path: format!("library/{}.wasm", detail.name),
-            version: detail.version.to_string(),
-            icon: detail.icon.clone(),
+        .map(|source| Index {
+            path: format!("library/{}.wasm", source.name),
+            source: source.clone(),
         })
-        .collect::<Vec<Source>>();
+        .collect::<Vec<Index>>();
 
     let file = std::fs::File::create(path.join("index.json"))?;
     serde_json::to_writer(&file, &sources)?;
